@@ -5,18 +5,31 @@ from ..util import client, result_cache,util
 from terminal import confirm,green
 import json
 
-def update(clusterId, nodes=None, groupName='group', mount=None, image=None, user_data=None, env=None, yes=False, show_json=False):
+def update(clusterId, nodes=None, groupName='group', mount=None, image=None, user_data=None, env=None, yes=False,
+           spot_price_limit=None,
+           show_json=False):
 
     clusterId = result_cache.get(clusterId, 'clusters', True)
 
     desc = {}
+    desc['Groups'] = {}
+    groupName = result_cache.get(groupName, 'groups')
+    desc['Groups'][groupName] = { }
 
     if nodes!=None and nodes>=0:
         v = int(nodes)
-        groupName = result_cache.get(groupName, 'groups')
-        desc['Groups']={}
-        desc['Groups'][groupName] = {"DesiredVMCount": v}
+        desc['Groups'][groupName]["DesiredVMCount"]=v
 
+    if spot_price_limit is not None:
+        spot_price_limit = float(spot_price_limit)
+        # if not resource_type == 'Spot':
+        #     raise Exception('spot_price_limit works only if resource_type is Spot')
+
+        if spot_price_limit > 0:
+            desc['Groups'][groupName]['SpotPriceLimit'] = spot_price_limit
+            desc['Groups'][groupName]['SpotStrategy'] = 'SpotWithPriceLimit'
+        else:
+            desc['Groups'][groupName]['SpotStrategy'] = 'SpotAsPriceGo'
 
     if image:
         desc['ImageId'] = image
@@ -94,3 +107,4 @@ def trans_env(env):
         arr = item.split(':',1)
         t.append( {'key': arr[0], 'value': arr[1] if len(arr)==2 else ''} )
     return t
+
