@@ -2,11 +2,11 @@ from ..util import config,client,oss_client,util
 from terminal import green,bold,yellow
 from .. import const
 from ..const import CMD
+import re
+FALSE_ARR = ['', 'null', 'None', 'false', 'False','0']
 
-FALSE_ARR = ['', 'null', 'None', 'false', 'False']
-
-def all(region=None, osspath=None, locale=None, image=None, type=None, version=None, ssl=None, god=None):
-    if not region and not osspath and not locale and not image and not type and not version and not ssl and not god:
+def all(region=None, osspath=None, locale=None, image=None, type=None, cluster=None, qsubuser=None, version=None, ssl=None, god=None):
+    if not region and not osspath and not locale and not image and not type and not cluster and not qsubuser and not version and not ssl and not god:
         show_config()
     else:
         if region:
@@ -19,10 +19,14 @@ def all(region=None, osspath=None, locale=None, image=None, type=None, version=N
             update_image(image)
         if type:
             update_type(type)
+        if cluster:
+            update_cluster(cluster)
         if version:
             update_version(version)
         if ssl:
             update_ssl(ssl)
+        if qsubuser:
+            update_qsubuser(qsubuser)
         if god:
             update_god(god)
         print(green('done'))
@@ -45,7 +49,19 @@ def update_region(region):
             raise Exception(e)
 
 
+def update_qsubuser(qsubuser):
+    m = config.getConfigs(config.COMMON)
 
+    qsubuser = qsubuser.strip()
+    if qsubuser in FALSE_ARR:
+        config.removeConfig(config.COMMON, 'qsubuser')
+    else:
+        if re.match(r'^[0-9A-Za-z]+$', qsubuser):
+
+            m['qsubuser'] = qsubuser
+            config.setConfigs(config.COMMON, m)
+        else:
+            raise Exception('Invalid qsubuser, it should consist of letters and numbers ')
 
 
 def update_osspath(osspath):
@@ -100,12 +116,30 @@ def update_type(type):
         itMap = client.get_ins_type_map()
 
         if not itMap.get(type):
-            raise Exception("'%s' is invalid, type '%s it' for more" % (type, CMD))
+            raise Exception("'%s' is invalid, type '%s t' for more" % (type, CMD))
 
         m['defaulttype'] = type
         config.setConfigs(config.COMMON, m)
 
+def update_cluster(cluster):
+    cluster = cluster.strip()
+    if cluster in FALSE_ARR:
+        # remove
+        config.removeConfig(config.COMMON, 'defaultcluster')
+    else:
+        m = config.getConfigs(config.COMMON)
 
+        clusters = client.list_clusters()
+        clsIdMap = {}
+        for n in clusters.get('Items'):
+            clsIdMap[n.get('Id')] = 1
+
+        if not clsIdMap.get(cluster):
+            raise Exception("'%s' is invalid, type '%s c' for more" % (type, CMD))
+
+        m['defaultcluster'] = cluster
+        print(m)
+        config.setConfigs(config.COMMON, m)
 
 
 def update_version(version):
@@ -144,8 +178,8 @@ def update_god(god):
 
 def show_config():
     try:
-        arr = ['region','accesskeyid','accesskeysecret','version','osspath','locale', 'defaultimage','defaulttype','ssl','god',
-               'oss_region','oss_id','oss_key']
+        arr = ['region','accesskeyid','accesskeysecret','version','osspath','locale', 'defaultimage','defaulttype','defaultcluster','ssl','god',
+               'oss_region','oss_id','oss_key','qsubuser']
         opt = config.getConfigs(config.COMMON, arr)
         if not opt:
             raise Exception('error')
