@@ -28,6 +28,7 @@ def submit(cmd=None, job_name=None, description=None, cluster=None, timeout=None
            resource_type=None,
            nas_access_group=None,
            nas_file_system=None,
+           spot_price_limit=None,
             vpc_cidr_block = None,
            show_json=False,show_dag=False):
 
@@ -82,7 +83,8 @@ def submit(cmd=None, job_name=None, description=None, cluster=None, timeout=None
         'nas_access_group': nas_access_group,
         'nas_file_system': nas_file_system,
 
-        'vpc_cidr_block': vpc_cidr_block
+        'vpc_cidr_block': vpc_cidr_block,
+        'spot_price_limit': spot_price_limit
 
     }
 
@@ -235,6 +237,21 @@ def fix_by_opt(desc, opt, check_cluster):
             if not task_desc['AutoCluster'].get('ResourceType'):
                 task_desc['AutoCluster']['ResourceType'] = 'OnDemand'
 
+            # spot price limit
+            if opt.get('spot_price_limit'):
+                spot_price_limit = opt.get('spot_price_limit')
+
+                if spot_price_limit is not None:
+                    spot_price_limit = float(spot_price_limit)
+                    if not task_desc['AutoCluster'].get('ResourceType') == 'Spot':
+                        raise Exception('spot_price_limit works only if resource_type is Spot')
+
+                    if spot_price_limit > 0:
+                        task_desc['AutoCluster']['SpotPriceLimit'] = spot_price_limit
+                        task_desc['AutoCluster']['SpotStrategy'] = 'SpotWithPriceLimit'
+                    else:
+                        task_desc['AutoCluster']['SpotStrategy'] = 'SpotAsPriceGo'
+
             if opt.get('user_data'):
                 user_data_m = trans_user_data(opt['user_data'])
                 if not task_desc['AutoCluster'].get('UserData'):
@@ -249,8 +266,7 @@ def fix_by_opt(desc, opt, check_cluster):
             if opt.get('reserve_on_fail'):
                 task_desc['AutoCluster']['ReserveOnFail'] = opt.get('reserve_on_fail')
 
-            if opt.get('no_cache_support'):
-                task_desc['Mounts']['CacheSupport'] = not opt.get('no_cache_support')
+
 
             # vpc
             if opt.get('vpc_cidr_block') :
@@ -262,32 +278,36 @@ def fix_by_opt(desc, opt, check_cluster):
                     task_desc['AutoCluster']['Configs']['Networks']['VPC'] = {}
                 task_desc['AutoCluster']['Configs']['Networks']['VPC']['CidrBlock'] = opt.get('vpc_cidr_block')
 
-        if opt.get('nas_access_group'):
+        # mounts
+        if opt.get('no_cache_support'):
+            task_desc['Mounts']['CacheSupport'] = not opt.get('no_cache_support')
 
-            # if not task_desc.get('ClusterId'):
-            #     task_desc['AutoCluster']['Configs']['Mounts']['NAS']['AccessGroup'] = opt.get('nas_access_group').split(',')
-            # else:
-                task_desc['Mounts']['NAS']['AccessGroup'] = opt.get('nas_access_group').split(',')
+        if opt.get('nas_access_group'):
+            if not task_desc.get('Mounts'):
+                task_desc['Mounts'] = {}
+            if not task_desc['Mounts'].get('NAS'):
+                task_desc['Mounts']['NAS'] = {}
+            task_desc['Mounts']['NAS']['AccessGroup'] = opt.get('nas_access_group').split(',')
 
         if opt.get('nas_file_system'):
-            # if task_desc.get('AutoCluster'):
-            #     task_desc['AutoCluster']['Configs']['Mounts']['NAS']['FileSystem'] = opt.get('nas_file_system').split(',')
-            # else:
-                task_desc['Mounts']['NAS']['FileSystem'] = opt.get('nas_file_system').split(',')
-
-
+            if not task_desc.get('Mounts'):
+                task_desc['Mounts'] = {}
+            if not task_desc['Mounts'].get('NAS'):
+                task_desc['Mounts']['NAS'] = {}
+            task_desc['Mounts']['NAS']['FileSystem'] = opt.get('nas_file_system').split(',')
 
         if opt.get('docker'):
             extend(task_desc['Parameters']['Command']['EnvVars'], trans_docker(opt['docker']))
         if opt.get('env'):
             extend(task_desc['Parameters']['Command']['EnvVars'], trans_env(opt['env']))
 
-        mount_m = get_mount_map(task_desc.get('Mounts'))
+
+
         if opt.get('mount'):
-            extend(mount_m, trans_mount(opt['mount']))
+            extend_mount(task_desc, trans_mount(opt['mount']))
         if opt.get('read_mount'):
-            extend(mount_m, trans_mount(opt['read_mount']))
-        extend_mount(task_desc, mount_m)
+            extend_mount(task_desc, trans_mount(opt['read_mount']))
+
 
 
         if opt.get('write_mount'):
@@ -316,20 +336,20 @@ def get_mount_map(mounts):
     return m
 
 def extend_mount(desc, mount_m):
-    desc['Mounts']['Entries'] = []
+    if not desc['Mounts'].get('Entries'):
+        desc['Mounts']['Entries'] = []
+
+    # 去重
+    i = 0
+    for n in desc['Mounts']['Entries']:
+        if mount_m.get(n['Source']):
+            del desc['Mounts']['Entries'][i]
+            i=i-1
+        i += 1
+
+    ####################################################
     for k,v in mount_m.items():
         if k.startswith('oss://') or k.startswith('nas://'):
-
-            # desc['InputMapping'][k] = v
-            # desc['OutputMapping'][v] = k
-        #elif k.startswith('nas://'):
-            # desc['AutoCluster']['Configs']['Mounts']['Entries'] = []
-            # desc['AutoCluster']['Configs']['Mounts']['Entries'].append({
-            #     "Destination": v,
-            #     "Source": k,
-            #     "WriteSupport": True
-            # })
-
             desc['Mounts']['Entries'].append({
                 "Destination": v,
                 "Source": k,
@@ -419,13 +439,12 @@ def trans_file_to_job_desc(file, check_cluster):
                 extend(task_desc['Parameters']['Command']['EnvVars'], trans_docker(cf.get(DEFAULT,'docker')))
 
 
-            mount_m = get_mount_map(task_desc.get('Mounts'))
 
             if cf.has_option(DEFAULT,'mount'):
-                extend(mount_m , trans_mount(cf.get(DEFAULT,'mount')))
+                extend_mount(task_desc , trans_mount(cf.get(DEFAULT,'mount')))
             if cf.has_option(DEFAULT,'read_mount'):
-                extend(mount_m, trans_mount(cf.get(DEFAULT,'read_mount')))
-            extend_mount(task_desc, mount_m)
+                extend_mount(task_desc, trans_mount(cf.get(DEFAULT,'read_mount')))
+
 
 
 
@@ -441,22 +460,6 @@ def trans_file_to_job_desc(file, check_cluster):
                 extend(task_desc['AutoCluster']['UserData'], user_data_m)
 
 
-            if cf.has_option(DEFAULT, 'nas_access_group'):
-                # if task_desc.get('AutoCluster'):
-                #     task_desc['AutoCluster']['Configs']['Mounts']['NAS']['AccessGroup'] = cf.get(DEFAULT,
-                #                                                                                  'nas_access_group').split(
-                #         ',')
-                # else:
-                    task_desc['Mounts']['NAS']['AccessGroup'] = cf.get(DEFAULT, 'nas_access_group').split(',')
-
-            if cf.has_option(DEFAULT, 'nas_file_system'):
-                # if task_desc.get('AutoCluster'):
-                #     task_desc['AutoCluster']['Configs']['Mounts']['NAS']['FileSystem'] = cf.get(DEFAULT,
-                #                                                                                 'nas_file_system').split(
-                #         ',')
-                # else:
-                    task_desc['Mounts']['NAS']['FileSystem'] = cf.get(DEFAULT, 'nas_file_system').split(',')
-
             if cf.has_option(DEFAULT, 'reserve_on_fail'):
                 task_desc['AutoCluster']['ReserveOnFail']=cf.getboolean(DEFAULT, 'reserve_on_fail')
 
@@ -511,6 +514,22 @@ def trans_file_to_job_desc(file, check_cluster):
             if cf.has_option(sec, 'resource_type'):
                 task_desc['AutoCluster']['ResourceType'] = cf.get(sec, 'resource_type')
 
+            # spot price limit
+            if cf.has_option(sec, 'spot_price_limit'):
+                spot_price_limit = cf.get(sec, 'spot_price_limit')
+
+                if spot_price_limit is not None:
+                    spot_price_limit = float(spot_price_limit)
+                    if not task_desc['AutoCluster'].get('ResourceType') == 'Spot':
+                        raise Exception('spot_price_limit works only if resource_type is Spot')
+
+                    if spot_price_limit > 0:
+                        task_desc['AutoCluster']['SpotPriceLimit'] = spot_price_limit
+                        task_desc['AutoCluster']['SpotStrategy'] = 'SpotWithPriceLimit'
+                    else:
+                        task_desc['AutoCluster']['SpotStrategy'] = 'SpotAsPriceGo'
+                
+
             if cf.has_option(sec, 'disk') and task_desc.get('AutoCluster'):
                 if not task_desc['AutoCluster'].get('Configs'):
                     task_desc['AutoCluster']['Configs'] = {}
@@ -531,21 +550,25 @@ def trans_file_to_job_desc(file, check_cluster):
                     task_desc['AutoCluster']['Configs']['Networks']['VPC'] = {}
                 task_desc['AutoCluster']['Configs']['Networks']['VPC']['CidrBlock'] = cf.get(sec, 'vpc_cidr_block')
 
-        if cf.has_option(sec,'nas_access_group'):
-            # if task_desc.get('AutoCluster'):
-            #     task_desc['AutoCluster']['Configs']['Mounts']['NAS']['AccessGroup'] = cf.get(sec,'nas_access_group').split(
-            #         ',')
-            # else:
-                task_desc['Mounts']['NAS']['AccessGroup'] = cf.get(sec,'nas_access_group').split(',')
+        # mounts
+        if cf.has_option(sec, 'no_cache_support'):
+            task_desc['Mounts']['CacheSupport'] = not cf.getboolean(sec, 'no_cache_support')
 
+        if cf.has_option(sec, 'nas_access_group'):
+            if not task_desc.get('Mounts'):
+                task_desc['Mounts'] = {}
+            if not task_desc['Mounts'].get('NAS'):
+                task_desc['Mounts']['NAS'] = {}
+            task_desc['Mounts']['NAS']['AccessGroup'] = cf.get(sec, 'nas_access_group').split(',')
 
         if cf.has_option(sec, 'nas_file_system'):
-            # if task_desc.get('AutoCluster'):
-            #     task_desc['AutoCluster']['Configs']['Mounts']['NAS']['FileSystem'] = cf.get(sec,
-            #                                                                                  'nas_file_system').split(
-            #         ',')
-            # else:
-                task_desc['Mounts']['NAS']['FileSystem'] = cf.get(sec, 'nas_file_system').split(',')
+            if not task_desc.get('Mounts'):
+                task_desc['Mounts'] = {}
+            if not task_desc['Mounts'].get('NAS'):
+                task_desc['Mounts']['NAS'] = {}
+            task_desc['Mounts']['NAS']['FileSystem'] = cf.get(sec, 'nas_file_system').split(',')
+
+
 
         if cf.has_option(sec, 'reserve_on_fail'):
             task_desc['AutoCluster']['ReserveOnFail'] = cf.getboolean(sec, 'reserve_on_fail')
@@ -557,15 +580,12 @@ def trans_file_to_job_desc(file, check_cluster):
             extend(task_desc['Parameters']['Command']['EnvVars'], trans_docker(cf.get(sec,'docker')))
 
 
-        if cf.has_option(sec, 'no_cache_support'):
-            task_desc['Mounts']['CacheSupport'] = not cf.getboolean(sec, 'no_cache_support')
-
-        mount_m = get_mount_map(task_desc.get('Mounts'))
         if cf.has_option(sec, 'mount'):
-            extend(mount_m,trans_mount(cf.get(sec, 'mount')))
+            extend_mount(task_desc, trans_mount(cf.get(sec, 'mount')))
+
         if cf.has_option(sec,'read_mount'):
-            extend(mount_m, trans_mount(cf.get(sec,'read_mount')))
-        extend_mount(task_desc, mount_m)
+            extend_mount(task_desc, trans_mount(cf.get(sec,'read_mount')))
+
 
 
         if cf.has_option(sec,'write_mount'):
