@@ -6,6 +6,7 @@ except:
 
 import os
 
+
 cf = ConfigParser.ConfigParser()
 
 def get_cfg_path():
@@ -18,9 +19,11 @@ def get_cfg_path():
 
 COMMON = 'common'
 
-def getConfigs(section, keys=['region','accesskeyid','accesskeysecret','osspath','locale','god',
-                              'defaultimage','defaulttype','version',
-                              'oss_region','oss_key','oss_id']):
+ALL = ['region','accesskeyid','accesskeysecret','osspath','locale','ssl','god',
+                              'defaultimage','defaulttype','defaultcluster','version',
+                              'oss_region','oss_key','oss_id','qsubuser']
+
+def getConfigs(section, keys=ALL):
     '''
     section: currently support 'common' only
     keys: array, example: ['region','accesskeyid']
@@ -61,7 +64,7 @@ def setConfig(section, key , value):
         return True
     return False
 
-def removeConfig(section, key):
+def removeConfig(section, key=ALL):
     cfg_path = get_cfg_path()
     if(os.path.exists(cfg_path)):
         try:
@@ -80,7 +83,7 @@ def removeConfig(section, key):
 def get_oss_path():
     pre_oss_path = getConfigs(COMMON,['osspath']).get('osspath')
     if not pre_oss_path:
-        raise Exception('osspath is unset, type: "bcs config -h" for more help')
+        raise Exception('Not found osspath, type: "bcs set -h" for more help')
 
     pre_oss_path = '%s/' % pre_oss_path.rstrip('/')
     return pre_oss_path
@@ -95,6 +98,9 @@ def getRegion():
     else:
         raise Exception('you need to login first')
 
+def get_qsubuser():
+    qsubuser = getConfigs(COMMON, ['qsubuser']).get('qsubuser')
+    return qsubuser if qsubuser else 'root'
 
 def get_oss_region():
     m= getConfigs(COMMON, ['region','oss_region'])
@@ -105,4 +111,21 @@ def get_oss_region():
     else:
         raise Exception('you need to login first')
 
+def get_default_image():
+    img = getConfigs(COMMON, ['defaultimage']).get('defaultimage')
+    if not img:
+        raise Exception('No found default image\n  using:"bcs set -i <img-id>" to set default image\n  type: "bcs set -h" for more help')
+    return img
 
+def get_default_instance_type():
+    img = getConfigs(COMMON, ['defaulttype']).get('defaulttype')
+    if not img:
+        raise Exception('No found default instance type\n  using:"bcs set -t <instance-type>" to set default instance type\n  type: "bcs set -h" for more help')
+    return img
+
+
+def get_default_instance_cluster():
+    img = getConfigs(COMMON, ['defaultcluster']).get('defaultcluster')
+    if not img:
+        raise Exception('No found default cluster\n  using:"bcs set -c <cluster-id>" to set default cluster\n  type: "bcs set -h" for more help')
+    return img
\ No newline at end of file
